django_turnit.management.commands package
=========================================

.. automodule:: django_turnit.management.commands
    :members:
    :undoc-members:
    :show-inheritance:

Submodules
----------

django_turnit.management.commands.turnit module
-----------------------------------------------

.. automodule:: django_turnit.management.commands.turnit
    :members:
    :undoc-members:
    :show-inheritance:


